==> spring-batch-integration-4.3.5-sources.jar: org/springframework/batch/integration/chunk/AsynchronousFailureException.java <==
/*
 * Copyright 2006-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.batch.integration.chunk;

import org.springframework.batch.item.ItemWriterException;

/**
 * Exception indicating that a failure or early completion condition was
 * detected in a remote worker.
 * 
 * @author Dave Syer
 * 
 */
public class AsynchronousFailureException extends ItemWriterException {

	private static final long serialVersionUID = 1L;

	/**
	 * Create a new {@link AsynchronousFailureException} based on a message and
	 * another exception.
	 * 
	 * @param message
	 *            the message for this exception
	 * @param cause
	 *            the other exception
	 */
	public AsynchronousFailureException(String message, Throwable cause) {
		super(message, cause);
	}

	/**
	 * Create a new {@link AsynchronousFailureException} based on a message.
	 * 
	 * @param message
	 *            the message for this exception
	 */
	public AsynchronousFailureException(String message) {
		super(message);
	}

}

==> spring-batch-integration-5.2.2-sources.jar: org/springframework/batch/integration/chunk/AsynchronousFailureException.java <==
/*
 * Copyright 2006-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.batch.integration.chunk;

import org.springframework.batch.item.ItemWriterException;

/**
 * Exception indicating that a failure or early completion condition was detected in a
 * remote worker.
 *
 * @author Dave Syer
 *
 */
public class AsynchronousFailureException extends ItemWriterException {

	private static final long serialVersionUID = 1L;

	/**
	 * Create a new {@link AsynchronousFailureException} based on a message and another
	 * exception.
	 * @param message the message for this exception
	 * @param cause the other exception
	 */
	public AsynchronousFailureException(String message, Throwable cause) {
		super(message, cause);
	}

	/**
	 * Create a new {@link AsynchronousFailureException} based on a message.
	 * @param message the message for this exception
	 */
	public AsynchronousFailureException(String message) {
		super(message);
	}

}
